[PARAMETER]

MyTex		tex0	value	default
MyNormal	tex1	value	default
MySpec		tex2	value	default
ShadowMap1	tex4	value	ShadowMap1

[VERTEX]

uniform float WaterHeight;

varying vec3 Light, Half;

void main ()
{
	vec3 Normal = normalize(gl_NormalMatrix * gl_Normal);
	vec3 Tangent = normalize(gl_NormalMatrix * gl_Color.xyz);
	vec3 Bitangent = cross(Normal, Tangent);

	vec3 tmpLight = normalize(gl_LightSource[0].position.xyz);
	Light.x = dot(tmpLight, Tangent);
	Light.y = dot(tmpLight, Bitangent);
	Light.z = dot(tmpLight, Normal);
	
	vec3 tmpHalf = normalize(gl_LightSource[0].halfVector.xyz );
	Half.x = dot(tmpHalf, Tangent);
	Half.y = dot(tmpHalf, Bitangent);
	Half.z = dot(tmpHalf, Normal);

	gl_TexCoord[1] = gl_TextureMatrix[1] * gl_ModelViewMatrix * gl_Vertex;

	gl_TexCoord[0] = gl_MultiTexCoord0;

	gl_ClipVertex = gl_ModelViewMatrix * gl_Vertex;	
	gl_Position= ftransform();
}

[FRAGMENT]

uniform sampler2DShadow ShadowMap1;
uniform sampler2D MyTex;
uniform sampler2D MyNormal;
uniform sampler2D MySpec;

varying vec3 Light, Half;

void main ()
{
	vec4 color= texture2D(MyTex,gl_TexCoord[0].st);

	vec4 diffuse = gl_LightSource[0].diffuse;
	vec4 ambient = gl_LightSource[0].ambient;
	vec4 specular = gl_LightSource[0].specular * texture2D(MySpec,gl_TexCoord[0].st);

	float shadow;
	if( gl_TexCoord[1].x < 0.0 || gl_TexCoord[1].x > 1.0 || gl_TexCoord[1].y < 0.0 || gl_TexCoord[1].y > 1.0 )
	{
		shadow = 1.0;
	}
	else
	{
		float depth = shadow2DProj(ShadowMap1, gl_TexCoord[1]).x;
		shadow = (depth > gl_TexCoord[1].z/gl_TexCoord[1].w) ? 1.0 : 0.3;
	}

	vec3 NV = texture2D(MyNormal,gl_TexCoord[0].st).xyz;
	NV = normalize(NV*2.0 - 1.0);
	vec3 LV = Light;
	float NdotL = max(dot(NV,LV),0.0);
	
	float NdotH=0.0;
	vec3 HV = normalize(Half);
	if( NdotL > 0.0 && shadow > 0.3 )
	{
		NdotH = max(dot(NV, HV), 0.0);
	}

	gl_FragColor = color*(ambient + diffuse*NdotL*shadow) + specular*pow(NdotH,30.0);
	gl_FragColor.a = color.a;
}
