[PARAMETER]

WaveMap		tex2	value	waves.jpg
ReflectionMap	tex3	value	ReflectionMap
RefractionMap	tex4	value	RefractionMap
Time		float	value	Time
CamX		float	value	CamX
CamY		float	value	CamY
CamZ		float	value	CamZ


[VERTEX]

varying vec3  EyeVec;

uniform float Time;
uniform float CamX;
uniform float CamY;
uniform float CamZ;

void main (void)
{
	vec3 EyePos = vec3(CamX, CamY, CamZ);

	EyeVec = gl_Vertex.xyz-EyePos.xyz;

	gl_TexCoord[0] = gl_TextureMatrix[0]*gl_Vertex;
	gl_TexCoord[1] = gl_Vertex*0.01+Time*0.02;
	gl_TexCoord[2] = gl_Vertex*0.02+Time*0.02;

	gl_Position = ftransform();

}

[FRAGMENT]

uniform sampler2D WaveMap;
uniform sampler2D ReflectionMap;
uniform sampler2D RefractionMap;

varying vec3  EyeVec;


void main (void)
{

	float cFresnelBias = 0.05;
	vec3 cDeepColor = vec3(0.0, 0.35, 0.70);
	vec3 cShallowColor = vec3(0.0, 0.3, 0.6);

	vec3 wave0 = texture2D(WaveMap, gl_TexCoord[1].xz).xyz;    
	vec3 wave1 = texture2D(WaveMap, gl_TexCoord[2].xz).xyz;
	vec3 wave = normalize(wave0 + wave1 - vec3(1.0, 1.0, 0.0));	

	
	float fDist = 10.0/(length(EyeVec) - 0.3);

	float facing = 1.0+EyeVec.y*fDist*(0.1-wave.y*0.01);
	float fresnel = cFresnelBias + (1.0-cFresnelBias)*pow(facing, 2.00);

	vec3 waterColor = mix(cDeepColor, cShallowColor, facing);

	vec2 waveJitter = wave.xy*(fDist*0.1);
	waveJitter.y = abs(waveJitter.y);

	vec3 reflecUV = gl_TexCoord[0].xyw;
	reflecUV.xy -= waveJitter*75.0*reflecUV.z;
	vec4 reflectColor = texture2DProj(ReflectionMap, (reflecUV * -0.05));

	reflecUV = gl_TexCoord[0].xyw;
	reflecUV.xy -= waveJitter*35.0*reflecUV.z;
	vec4 refractColor = texture2DProj(RefractionMap, reflecUV);

	fresnel = fresnel + (fresnel * 0.5);

	
	if (fresnel > 0.99)
		fresnel = 1.0;

 
 
	vec3 finalColor = mix(refractColor.rgb, reflectColor.rgb, 0.65);
     
	gl_FragColor = vec4(mix(finalColor, cDeepColor, fresnel * 0.2), 1.0);

 
}
